@@ -61,7 +61,7 @@ CombineTrials <- function(in.dirs, out.dir, copy = TRUE)
    }
 }
 
-EEMD <-function(sig, tt, noise.amp, trials, nimf, trials.dir = NULL, verbose = TRUE, spectral.method = "arctan", diff.lag = 1, tol = 5, max.sift = 200, stop.rule = "type5", boundary = "wave", sm = "none", smlevels = c(1), spar = NULL, max.imf = 100, interm = NULL) 
+EEMD <-function(sig, tt, noise.amp, trials, nimf, trials.dir = NULL, verbose = TRUE, spectral.method = "arctan", diff.lag = 1, tol = 5, max.sift = 200, stop.rule = "type5", boundary = "wave", sm = "none", smlevels = c(1), spar = NULL, max.imf = 100, interm = NULL, noise.type = "gaussian", noise.array = NULL) 
 {
 	#Performs the Ensemble Empirical Mode Decomposition as described in Huang and Wu (2008) A Review on the Hilbert Huang Transform Method and its Applications to Geophysical Studies
 	#It runs EMD on a given signal for N=TRIALS
@@ -70,7 +70,7 @@ EEMD <-function(sig, tt, noise.amp, trials, nimf, trials.dir = NULL, verbose = T
 	#INPUTS
         #   SIG is the time series
         #   TT is the sample times 
-        #   NOISE.AMP is the amplitude of the uniform random noise distribution
+        #   NOISE.AMP is the amplitude of the noise distribution (upper/lower cutoff if uniform, standard deviation if gaussian, ignored otherwise)
         #   TRIALS is the number of times to run EMD
         #   NIMF is the number of IMFs to be saved, IMFs past this number will be discarded
         #   TRIALS.DIR is the directory in which to put the EMD runs, if NULL, make a directory called "trials".  If TRIALS.DIR does not already exist, make it.
@@ -91,6 +91,9 @@ EEMD <-function(sig, tt, noise.amp, trials, nimf, trials.dir = NULL, verbose = T
         #   SPAR - User-defined smoothing parameter for spline, kernal, or local polynomial smoothign
         #   MAX.IMF - How many IMFs are allowed, IMFs above this number will not be recorded
         #   INTERM - specifies vector of periods to be excluded from IMFs to cope with mode mixing.  I do not use this; instead I use the EEMD method.
+        #   NOISE.TYPE - zero mean gaussian with standard deviation NOISE.AMP (if "gaussian" or unspecified), or "uniform" (absolute maximum/minimum amplitude), or "custom" (user defined noise matrix, expects NOISE.MATRIX)
+        #   NOISE.ARRAY - A TRIALS x LENGTH(TT) matrix of user-defined noise to use in place of gaussian or uniform noise.  NOISE.TYPE must be set to "custom" for this input to be used.
+
         
 	#OUTPUTS are saved to TRIALS.DIR in variable EMD.RESULT
 	
@@ -105,13 +108,32 @@ EEMD <-function(sig, tt, noise.amp, trials, nimf, trials.dir = NULL, verbose = T
 		print(paste("Created trial directory:",trials.dir))
 	}
 
+        if(!(noise.type  %in% c("uniform", "gaussian", "custom"))) {
+            stop(paste("Did not recognise noise.type option", noise.type,  "Please choose either ''uniform'' or ''gaussian''"))
+        }
+
+        if(noise.type == "custom") {
+            if(!is.null(noise.array)) {
+                if((dim(noise.array)[1] != trials) | dim(noise.array)[2] != length(tt)) {
+                    stop("You requested a custom noise array but either the number of rows did not equal the number of EEMD trials or the number of columns did not equal the signal length, or both.")
+                }
+            } else {
+                stop("If noise.type = \"custom\", then you must set noise.array equal to an array with the same number of rows as EEMD trials and the same number of columns as signal samples.")
+            }
+        }
+     
 	averaged.imfs=array(0,nimf*length(sig),dim=c(length(sig),nimf))
 	averaged.noise=array(0,length(sig),dim=c(length(sig),1))
 	averaged.residue=array(0,length(sig),dim=c(length(sig),1))
 	for (j in 1:trials)
 	{
-	
-		noise=runif(length(sig),min=noise.amp*-1, max=noise.amp)
+                if(noise.type == "uniform") {	
+		    noise=runif(length(sig),min=noise.amp*-1, max=noise.amp)
+                } else if (noise.type == "gaussian") {
+                    noise = rnorm(length(sig), mean = 0, sd = noise.amp)
+                } else if (noise.type == "custom") {
+                    noise <- noise.array[j, ]
+                }
 		tmpsig=sig+noise
 		emd.result=Sig2IMF(tmpsig,tt, spectral.method = spectral.method, diff.lag = diff.lag, 
                    tol = tol, max.sift = max.sift, stop.rule = stop.rule, boundary = boundary, 
@@ -370,7 +392,7 @@ Sig2IMF <- function(sig, tt, spectral.method = "arctan", diff.lag = 1, stop.rule
     #Danny Bowman
     #UNC Chapel Hill
 
-    emd.result=emd(sig, tt, max.sift=max.sift, stoprule=stop.rule, tol=tol, 
+    emd.result=EMD::emd(sig, tt, max.sift=max.sift, stoprule=stop.rule, tol=tol, 
         boundary=boundary,sm=sm,spar=spar, 
         check=FALSE, plot.imf=FALSE,max.imf=max.imf)
     emd.result$original.signal=sig
